==> haskell-project-template-0.2.0.1-47-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: project-template
version: 0.2.0.1
id: project-template-0.2.0.1-Hl6zZaUN8uEECBKNgaVA6E
key: project-template-0.2.0.1-Hl6zZaUN8uEECBKNgaVA6E
license: BSD-3-Clause
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/haskell-ide
synopsis: Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>
category: Development
abi: 6a12f92da3dbfeb863551a3f5a62b502
exposed: True
exposed-modules:
    Text.ProjectTemplate
import-dirs: /usr/lib/ghc-8.4.3/site-local/project-template-0.2.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/project-template-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/project-template-0.2.0.1
hs-libraries: HSproject-template-0.2.0.1-Hl6zZaUN8uEECBKNgaVA6E
depends:
    base-4.11.1.0 base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    text-1.2.3.0 bytestring-0.10.8.2 transformers-0.5.5.0 mtl-2.2.2
    conduit-1.3.0.2-VILpe2nHJJEI731JKcPDn
    conduit-extra-1.3.0-CTMTpryxYu83pL8nvfDx5f
    resourcet-1.2.1-HwvyG5Ro3dY2I74iZB2jB containers-0.5.11.0
    filepath-1.4.2 directory-1.3.1.5
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             conduit-1.3.0.2-VILpe2nHJJEI731JKcPDn=5128b3631ba5c225d63f54c8b3e56168
             conduit-extra-1.3.0-CTMTpryxYu83pL8nvfDx5f=2aaa3d36cab3444ad2d02f3352678cc7
             resourcet-1.2.1-HwvyG5Ro3dY2I74iZB2jB=d9ddc5f723b835717074cf86137c6377
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
haddock-html: /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-project-template-0.2.0.1-69-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: project-template
version: 0.2.0.1
id: project-template-0.2.0.1-HUSUtL1I6Vz2Hq91qMzKAc
key: project-template-0.2.0.1-HUSUtL1I6Vz2Hq91qMzKAc
license: BSD-3-Clause
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/haskell-ide
synopsis: Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>
category: Development
abi: 4f0d1145f16356a13fa6076bbc3ee8d0
exposed: True
exposed-modules:
    Text.ProjectTemplate
import-dirs: /usr/lib/ghc-8.4.3/site-local/project-template-0.2.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/project-template-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/project-template-0.2.0.1
hs-libraries: HSproject-template-0.2.0.1-HUSUtL1I6Vz2Hq91qMzKAc
depends:
    base-4.11.1.0 base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    text-1.2.3.0 bytestring-0.10.8.2 transformers-0.5.5.0 mtl-2.2.2
    conduit-1.3.0.3-jzrr6yU0OhECg2j6Ub1fi
    conduit-extra-1.3.0-ALJzKmUpen95OJ3wxMnzgR
    resourcet-1.2.1-Bs6WlRCMNNECIXXGat8zzJ containers-0.5.11.0
    filepath-1.4.2 directory-1.3.1.5
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             conduit-1.3.0.3-jzrr6yU0OhECg2j6Ub1fi=596f98d227d510fe8f1519d24dac743d
             conduit-extra-1.3.0-ALJzKmUpen95OJ3wxMnzgR=7158bea21e7ac6f77f9caee1971ab8de
             resourcet-1.2.1-Bs6WlRCMNNECIXXGat8zzJ=92ead6a5b5c9a7bdba7244f3ea39cc11
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
haddock-html: /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
